@@ -29,6 +29,10 @@ class Workspace(object):
         self._docs = {}
         self._lang_server = lang_server
 
+    @property
+    def documents(self):
+        return self._docs
+
     @property
     def root_path(self):
         return self._root_path
@@ -76,11 +80,14 @@ class Workspace(object):
         """
         files = config.find_parents(self._root_path, path, ['setup.py']) or []
         path = [os.path.dirname(setup_py) for setup_py in files]
-        path.extend(sys.path)
-        return path
 
-    def is_in_workspace(self, path):
-        return not self._root_path or os.path.commonprefix((self._root_path, path))
+        # Check to see if we're in a virtualenv
+        if 'VIRTUAL_ENV' in os.environ:
+            log.info("Using virtualenv %s", os.environ['VIRTUAL_ENV'])
+            path.extend(jedi.evaluate.sys_path.get_venv_path(os.environ['VIRTUAL_ENV']))
+        else:
+            path.extend(sys.path)
+        return path
 
 
 class Document(object):
